.. -*-restructuredtext-*-

django-soapbox provides simple site-wide and page-specific
announcements/messages for `Django <https://www.djangoproject.com>`_
sites. Simply install, begin adding messages in the admin, and then
use the provided template tag library to retrieve them.

Full documentation is included and `available online
<http://django-soapbox.readthedocs.org/>`_.
